@@ -11,6 +11,7 @@ import pytest
 from pikepdf import Array
 from pikepdf._core import Matrix, Rectangle
 from pikepdf.models import PdfMatrix
+from pikepdf.objects import Dictionary
 
 
 def allclose(m1, m2, abs_tol=1e-6):
@@ -49,6 +50,7 @@ class TestOldPdfMatrix:
         assert m.encode() == b'1.000000 0.000000 0.000000 1.000000 0.000000 0.000000'
 
     def test_matrix_inverse(self):
+        _np = pytest.importorskip('numpy')
         m = PdfMatrix(2, 0, 0, 1, 0, 3)
         minv_m = m.inverse() @ m
         assert allclose(minv_m, PdfMatrix.identity())
@@ -68,6 +70,21 @@ class TestMatrix:
     def test_default_is_identity(self):
         assert Matrix() == Matrix(1, 0, 0, 1, 0, 0)
 
+    def test_not_enough_args(self):
+        with pytest.raises(TypeError):
+            Matrix(1, 2, 3, 4, 5)
+
+    def test_tuple(self):
+        assert Matrix() == Matrix((1, 0, 0, 1, 0, 0))
+        with pytest.raises(ValueError):
+            Matrix((1, 2, 3, 4, 5))
+
+    def test_failed_object_conversion(self):
+        with pytest.raises(ValueError):
+            assert Matrix(Array([1, 2, 3]))
+        with pytest.raises(ValueError):
+            assert Matrix(Dictionary(Foo=1))
+
     def test_accessors(self):
         m = Matrix(1, 2, 3, 4, 5, 6)
         assert m.a == 1
@@ -86,6 +103,21 @@ class TestMatrix:
         expected = Matrix(0, 2, -2, 0, 4, 6)
         assert allclose(m2tr, expected)
 
+    def test_init_copy(self):
+        m = Matrix(1, 2, 3, 4, 5, 6)
+        m2 = Matrix(m)
+        assert m == m2
+
+    def test_init_from_objlist(self):
+        a = Array([1, 2, 3, 4, 5, 6])
+        assert Matrix(a.as_list()).shorthand == (1, 2, 3, 4, 5, 6)
+        b = Array([1, 2, 3, 4, 5])
+        with pytest.raises(ValueError, match='must have 6 elements'):
+            Matrix(b.as_list())
+        c = Array([1, 2, b"foo", 4, 5, 6])
+        with pytest.raises(ValueError, match='must be numeric'):
+            Matrix(c.as_list())
+
     def test_matmul(self):
         m = Matrix()
         scale = Matrix().scaled(3, 3)
@@ -144,3 +176,6 @@ class TestMatrix:
         assert (0, 0) < m.transform((1, 0)) < (1, 1)
         m = Matrix().rotated(-45)
         assert (0, 0) < m.transform((1, 0)) < (1, -1)
+
+    def test_latex(self):
+        assert '\\begin' in Matrix(1, 0, 0, 1, 0, 0)._repr_latex_()
